<?php

/**
 * @file
 * Contains the Juicebox style plugin.
 */

/**
 * Style plugin to render each item in an ordered or unordered list.
 *
 * @ingroup views_style_plugins
 */
class juicebox_style_plugin extends views_plugin_style {
  function option_definition() {
    $options = parent::option_definition();
    $options['width'] = array('default' => '100%'); 
    $options['height'] = array('default' => '100%'); 
    $options['image_field'] = array('default' => '');
    $options['image_field_style'] = array('default' => '');
    $options['thumb_field'] = array('default' => '');
    $options['thumb_field_style'] = array('default' => 'thumbnail');
    $options['title_field'] = array('default' => '');
    $options['caption_field'] = array('default' => '');
    $options['advanced'] = NULL;
    $options['advanced']['config'] = '';
    return $options;
  }

  function options_form(&$form, &$form_state) {
    parent::options_form($form, $form_state);
    // Get the active field options
    $fields_options = array();
    $field_options_images = array();
    $field_handlers = $this->display->handler->get_handlers('field');
    foreach ($field_handlers as $field => $handler) {
      if ($label = $handler->label()) {
        $name = $label;
      }
      else {
        $name = $handler->ui_name();
      }
      // Separate image fields from non-image fields
      if (isset($handler->field_info['type'])) {
        if ($handler->field_info['type'] == 'image') {
          $field_options_images[$field] = $name;
        }
        else {
          $field_options[$field] = $name;
        }
      }
      else {
        $field_options[$field] = $name;
      }
    }
    // Get available image style presets
    $presets = image_style_options(FALSE);

    $form['description'] = array(
      '#type' => 'markup',
      '#value' => '<div class="messages">' . t('Options for the Juicebox view.') . '</div>',
    );
    $form['width'] = array(
      '#type' => 'textfield',
      '#title' => t('Gallery Width'),
      '#default_value' => $this->options['width'],
      '#description' => t('Set the gallery width as a pixel value or a percentage.'),
    );
    $form['height'] = array(
      '#type' => 'textfield',
      '#title' => t('Gallery Heigth'),
      '#default_value' => $this->options['height'],
      '#description' => t('Set the gallery height as a pixel value or a percentage.'),
    );

    $form['image_field'] = array(
      '#type' => 'select',
      '#title' => t('Main Image Field'),
      '#default_value' => $this->options['image_field'],
      '#description' => t('Choose the field from the view that should be used for each main image in the Juicebox gallery. This must be an "image" field.'),
      '#options' => $field_options_images,
    );
    $form['image_field_style'] = array(
      '#type' => 'select',
      '#title' => t('Main Image Field Style'),
      '#default_value' => $this->options['image_field_style'],
      '#description' => t('Choose the style formatter for the main image. Note that any style or formatting settings configured on the field itself will be ignored and this style setting will always be used.'),
      '#options' => $presets,
      '#empty_option' => t('None (original image)'),
    );
    $form['thumb_field'] = array(
      '#type' => 'select',
      '#title' => t('Thumbnail Field'),
      '#default_value' => $this->options['thumb_field'],
      '#description' => t('Choose the field from the view that should be used for each thumbnail in the Juicebox gallery. This must be an "image" field. Typically you will simply choose the same value that you set in the "Main Image Field" option above.'),
      '#options' => $field_options_images,
    );
    $form['thumb_field_style'] = array(
      '#type' => 'select',
      '#title' => t('Thumbnail Field Style'),
      '#default_value' => $this->options['thumb_field_style'],
      '#description' => t('Choose the style formatter for the thumbnail. Note that any style or formatting settings configured on the field itself will be ignored and this style setting will always be used.'),
      '#options' => $presets,
      '#empty_option' => t('None (original image)'),
    );
    $form['title_field'] = array(
      '#type' => 'select',
      '#title' => t('Title Field'),
      '#default_value' => $this->options['title_field'],
      '#description' => t('Choose the field from the view that should be used for the title of each image in the Juicebox gallery. The raw markup generated by views for this field will be used and any style or formatting settings configured on the field itself will be respected.'),
      '#options' => $field_options,
      '#empty_option' => t('None'),
    );
    $form['caption_field'] = array(
      '#type' => 'select',
      '#title' => t('Caption Field'),
      '#default_value' => $this->options['caption_field'],
      '#description' => t('Choose the field from the view that should be used for the caption of each image in the Juicebox gallery. The raw markup generated by views for this field will be used and any style or formatting settings configured on the field itself will be respected.'),
      '#options' => $field_options,
      '#empty_option' => t('None'),
    );
    $form['advanced'] = array(
      '#type' => 'fieldset',
      '#title' => t('Advanced Options'),
      '#collapsible' => TRUE,
      '#collapsed' => FALSE,
    );
    $form['advanced']['config'] = array(
      '#type' => 'textarea',
      '#title' => t('Manual configuraton options'),
      '#default_value' => $this->options['advanced']['config'],
      '#description' => t('Define any general configuration options that should be used in this gallery (see: http://www.juicebox.net/support/config_options/). Add one per line in the format <strong>optionName = "optionValue"</strong>. These will be inserted <em>as is</em> within the configuration XML used in this gallery so take care to ensure your formatting is correct.'),
    );
  }

  function validate() {
    $errors = parent::validate();
    if ($this->display->handler->use_pager()) {
      $errors[] = t('The Juicebox style cannot be used with a pager. Disable the "Use pager" option for this display.');
    }
    return $errors;
  }

}
